from astropy.utils.data import download_file
import matplotlib.pyplot as plt
from hipparchus import Template, EchelleSpectrum, cross_corr

proxima_spectrum_url = 'https://drive.google.com/uc?export=download&id=1I7E1x1XRjcxXNQXiuaajb_Jz7Wn2N_Eo'
proxima_spectrum_path = download_file(proxima_spectrum_url, cache=True,
                                      show_progress=False)
spectrum = EchelleSpectrum.from_e2ds(proxima_spectrum_path)

template_2500_h2o_url = 'https://drive.google.com/uc?export=download&id=1RIXBl3L3J_R9PQ-k_0BqAtO-9zYn2mag'
template_2500_h2o_path = download_file(template_2500_h2o_url, cache=True,
                                       show_progress=False)
template_2500_h2o = Template.from_npy(template_2500_h2o_path)

counter = -1
for order in spectrum.orders:
    if order.wavelength.mean() > 5800:
        counter += 1
        ccf = cross_corr(order, template_2500_h2o)
        ccf.plot(label='{0:.0f} $\AA$'.format(order.wavelength.mean()),
                 color=plt.cm.magma(counter/20))
plt.legend(loc='lower right', fontsize=8)
plt.xlabel('$\Delta v$ [km/s]')
plt.ylabel('CCF')